@@ -29,6 +29,12 @@ class AddCatalogRelationsRequest(RpcRequest):
 	def set_CatalogId(self,CatalogId):
 		self.add_query_param('CatalogId',CatalogId)
 
+	def get_SecurityToken(self):
+		return self.get_query_params().get('SecurityToken')
+
+	def set_SecurityToken(self,SecurityToken):
+		self.add_query_param('SecurityToken',SecurityToken)
+
 	def get_ApiIds(self):
 		return self.get_query_params().get('ApiIds')
 
