@@ -147,4 +147,10 @@ class CreateApiRequest(RpcRequest):
 		return self.get_query_params().get('RequestConfig')
 
 	def set_RequestConfig(self,RequestConfig):
-		self.add_query_param('RequestConfig',RequestConfig)
\ No newline at end of file
+		self.add_query_param('RequestConfig',RequestConfig)
+
+	def get_ResultBodyModel(self):
+		return self.get_query_params().get('ResultBodyModel')
+
+	def set_ResultBodyModel(self,ResultBodyModel):
+		self.add_query_param('ResultBodyModel',ResultBodyModel)
\ No newline at end of file
