@@ -27,4 +27,10 @@ class DeleteAllTrafficSpecialControlRequest(RpcRequest):
 		return self.get_query_params().get('TrafficControlId')
 
 	def set_TrafficControlId(self,TrafficControlId):
-		self.add_query_param('TrafficControlId',TrafficControlId)
\ No newline at end of file
+		self.add_query_param('TrafficControlId',TrafficControlId)
+
+	def get_SecurityToken(self):
+		return self.get_query_params().get('SecurityToken')
+
+	def set_SecurityToken(self,SecurityToken):
+		self.add_query_param('SecurityToken',SecurityToken)
\ No newline at end of file
