@@ -27,4 +27,10 @@ class DeleteCatalogRequest(RpcRequest):
 		return self.get_query_params().get('CatalogId')
 
 	def set_CatalogId(self,CatalogId):
-		self.add_query_param('CatalogId',CatalogId)
\ No newline at end of file
+		self.add_query_param('CatalogId',CatalogId)
+
+	def get_SecurityToken(self):
+		return self.get_query_params().get('SecurityToken')
+
+	def set_SecurityToken(self,SecurityToken):
+		self.add_query_param('SecurityToken',SecurityToken)
\ No newline at end of file
