@@ -6,10 +6,10 @@
 # "License"); you may not use this file except in compliance
 # with the License.  You may obtain a copy of the License at
 #
-#
 #     http://www.apache.org/licenses/LICENSE-2.0
 #
 #
+#
 # Unless required by applicable law or agreed to in writing,
 # software distributed under the License is distributed on an
 # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -18,35 +18,19 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
-from aliyunsdkcloudapi.endpoint import endpoint_data
-
 class DeletePluginRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'DeletePlugin','apigateway')
-		self.set_method('POST')
 
-		if hasattr(self, "endpoint_map"):
-			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
-		if hasattr(self, "endpoint_regional"):
-			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
-
-	def get_PluginId(self): # String
-		return self.get_query_params().get('PluginId')
-
-	def set_PluginId(self, PluginId):  # String
-		self.add_query_param('PluginId', PluginId)
-	def get_SecurityToken(self): # String
+	def get_SecurityToken(self):
 		return self.get_query_params().get('SecurityToken')
 
-	def set_SecurityToken(self, SecurityToken):  # String
-		self.add_query_param('SecurityToken', SecurityToken)
-	def get_Tags(self): # RepeatList
-		return self.get_query_params().get('Tag')
+	def set_SecurityToken(self,SecurityToken):
+		self.add_query_param('SecurityToken',SecurityToken)
 
-	def set_Tags(self, Tag):  # RepeatList
-		for depth1 in range(len(Tag)):
-			if Tag[depth1].get('Value') is not None:
-				self.add_query_param('Tag.' + str(depth1 + 1) + '.Value', Tag[depth1].get('Value'))
-			if Tag[depth1].get('Key') is not None:
-				self.add_query_param('Tag.' + str(depth1 + 1) + '.Key', Tag[depth1].get('Key'))
+	def get_PluginId(self):
+		return self.get_query_params().get('PluginId')
+
+	def set_PluginId(self,PluginId):
+		self.add_query_param('PluginId',PluginId)
\ No newline at end of file
