@@ -21,4 +21,10 @@ from aliyunsdkcore.request import RpcRequest
 class DescribeCatalogsRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'DescribeCatalogs','apigateway')
\ No newline at end of file
+		RpcRequest.__init__(self, 'CloudAPI', '2016-07-14', 'DescribeCatalogs','apigateway')
+
+	def get_SecurityToken(self):
+		return self.get_query_params().get('SecurityToken')
+
+	def set_SecurityToken(self,SecurityToken):
+		self.add_query_param('SecurityToken',SecurityToken)
\ No newline at end of file
