@@ -29,6 +29,12 @@ class RemoveCatalogRelationRequest(RpcRequest):
 	def set_CatalogId(self,CatalogId):
 		self.add_query_param('CatalogId',CatalogId)
 
+	def get_SecurityToken(self):
+		return self.get_query_params().get('SecurityToken')
+
+	def set_SecurityToken(self,SecurityToken):
+		self.add_query_param('SecurityToken',SecurityToken)
+
 	def get_ApiId(self):
 		return self.get_query_params().get('ApiId')
 
